Module transforms

Module transforms 

Transformation functions

Enums

TransformType
The different types of transformations which can be applied to numeric data.

Functions

apply_transform
Applies a specified transformation to a numeric data series.
log_transform
Applies the natural logarithm transformation to a numeric data series.
sqrt_transform
Applies the square root transformation to a numeric data series.
tanh_transform
Applies the hyperbolic tangent transformation to a numeric data series.