TransformType

Enum TransformType 

pub enum TransformType {
    Sqrt,
    Log,
    Tanh,
}
The different types of transformations which can be applied to numeric data.

Variants



Sqrt

Applies the square root transformation over the data.

This will compress large values more than small values, which can be useful for stabilizing variance or reducing the distortion effects of outliers.



Log

Applies the natural logarithm transformation over the data.

This will aggressively compress large values and expand small values which can be useful for stabilizing variance, normalizing skewed distributions, and linearizing exponential relationships.



Tanh

Applies the hyperbolic tangent transformation over the data.

This will squash values into the bounded range of (-1, 1) preserving the sign and relative magnitude which can be useful for dampening tails and emphasizing variations near zero.