pub fn sqrt_transform<T>(data: &[T]) -> Vec<f64>Expand description
Applies the square root transformation to a numeric data series.
This will compress large values more than small values, which can be useful for stabilizing variance or reducing the distortion effects of outliers in the data series.
NOTE: The square root transform is relatively weak at taming tails and is best used when only slight tail dampening is needed.
Example
use quant_mathema::transforms::sqrt_transform;
let data = vec![0.0, 1.0, 4.0, 9.0, 16.0];
let data_sqrt_trans = sqrt_transform(&data);