Transformation functions
Enums
- Transform
Type - The different types of transformations which can be applied to numeric data.
Functions
- apply_
transform - Applies a specified transformation to a numeric data series.
- log_
transform - Applies the natural logarithm transformation to a numeric data series.
- sqrt_
transform - Applies the square root transformation to a numeric data series.
- tanh_
transform - Applies the hyperbolic tangent transformation to a numeric data series.